previous method
Go one step back. A no-op on the first step (and for custom tooltips that do not want a back action — the default is safe).
Implementation
@override
void previous() => _dispatch(const UserPrevious());
Go one step back. A no-op on the first step (and for custom tooltips that do not want a back action — the default is safe).
@override
void previous() => _dispatch(const UserPrevious());