ArmTimeoutEffect class

Arm the wait-for-target timer; emitted exactly when entering waiting.

Inheritance
Annotations

Constructors

ArmTimeoutEffect({required Duration timeout})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override