HintActive class

Step shown: target mounted, scrim with a hole and tooltip are active.

Inheritance
Annotations

Constructors

HintActive({required HintTour tour, required int stepIndex})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
isActive → bool
no setterinherited
isIdle → bool
no setterinherited
isWaiting → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepIndex → int
final
targetId → String
The current step's target id (for diagnostics on abort).
no setter
tour → HintTour
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override