HintIdle class

No tour: zero engine widgets in the tree.

Inheritance
Annotations

Constructors

HintIdle()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isActive bool
no setterinherited
isIdle bool
no setterinherited
isWaiting bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepIndex int?
no setterinherited
tour HintTour?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override