UserPrevious class

Go one step back. On the first step — a no-op (there is nothing to go back to; the waiting timer is NOT re-armed, so spamming back does not extend the wait).

Inheritance
Annotations

Constructors

UserPrevious()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited