WaitTimeout class

The wait-for-target timeout elapsed (the controller generates this event from the timer armed via ArmTimeoutEffect).

Inheritance
Annotations

Constructors

WaitTimeout()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited