extraPositions property
Preferred sides of the extra slots, in order (index == extraId).
Implementation
final List<TooltipPosition> extraPositions;
Preferred sides of the extra slots, in order (index == extraId).
final List<TooltipPosition> extraPositions;