position property
Preferred side; TooltipPosition.auto — the side with the most free space between the hole and the screen edge.
Implementation
final TooltipPosition position;
Preferred side; TooltipPosition.auto — the side with the most free space between the hole and the screen edge.
final TooltipPosition position;