holeOf property
The target (scrim hole) rect in global overlay coordinates, resolved at paint time (see TooltipTailPainter.holeOf).
Implementation
final Rect Function() holeOf;
The target (scrim hole) rect in global overlay coordinates, resolved at paint time (see TooltipTailPainter.holeOf).
final Rect Function() holeOf;