HintPosition class sealed
Target position for rendering the scrim/tooltip.
PositionedHint — the target is mounted and the compositor knows its position; UnpositionedHint — the target is not in the tree (yet/already), there is no position.
- Implementers
- Annotations
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited