UnpositionedHintResolver class

A resolver that never yields a position: used in waiting mode when the target does not exist yet and the scrim is drawn fully (no hole).

Implemented types

Constructors

UnpositionedHintResolver()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve() → HintPosition
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited