lookup method
Current registration for id, or null if the target is not mounted.
Implementation
HintTargetRegistration? lookup(String id) => _byId[id];
Current registration for id, or null if the target is not mounted.
HintTargetRegistration? lookup(String id) => _byId[id];