previous method
void
previous()
Go one step back. A no-op on the first step (and for custom tooltips that do not want a back action — the default is safe).
Implementation
void previous() {}
Go one step back. A no-op on the first step (and for custom tooltips that do not want a back action — the default is safe).
void previous() {}