clear abstract method
void
clear()
Forget everything. A debug/dev tool — the production "re-show" is a version bump, but a hard clear is handy in debug builds and tests.
Implementation
void clear();
Forget everything. A debug/dev tool — the production "re-show" is a version bump, but a hard clear is handy in debug builds and tests.
void clear();