clear method
Forget everything. A debug/dev tool — the production "re-show" is a version bump, but a hard clear is handy in debug builds and tests.
Implementation
@override
void clear() => _shown.clear();
Forget everything. A debug/dev tool — the production "re-show" is a version bump, but a hard clear is handy in debug builds and tests.
@override
void clear() => _shown.clear();