InMemoryHintTourFactory class

In-memory factory — tests, previews, local tours.

Implemented types

Constructors

InMemoryHintTourFactory(Map<String, HintTour> _tours)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetch(String id) Future<HintTour>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited