showActions property
false — an informational slot without the action button row (extra tooltips); the primary tooltip keeps its Skip/Back/Next/Done controls.
Implementation
final bool showActions;
false — an informational slot without the action button row (extra tooltips); the primary tooltip keeps its Skip/Back/Next/Done controls.
final bool showActions;