semanticsLabel property
Screen-reader label; null — no Semantics wrapper (a cheap option that does not touch the tree in the common case).
Implementation
final String? semanticsLabel;
Screen-reader label; null — no Semantics wrapper (a cheap option that does not touch the tree in the common case).
final String? semanticsLabel;