HintTransition class

The result of a single HintMachine.dispatch: new state + effects.

Annotations

Constructors

HintTransition({required HintState state, required List<HintEffect> effects})
const

Properties

effects List<HintEffect>
Immutable list of effects the controller must apply.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state HintState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited