HintWaiting class

Waiting for the current step's target to appear (wait-for-target; the timeout is driven by the controller via ArmTimeoutEffect).

Inheritance
Annotations

Constructors

HintWaiting({required HintTour tour, required int stepIndex})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isActive bool
no setterinherited
isIdle bool
no setterinherited
isWaiting bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepIndex int
final
targetId String
The id being waited for on this step.
no setter
tour HintTour
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override