PositionedHint class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
size
→ Size
-
Target size (
LayerLink.leaderSize).
final
-
translation
→ Offset
-
Offset of the target's top-left corner in overlay coordinates (the
space where the CompositedTransformFollower wrapper lives).
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override