lerp method
Linearly interpolate with another ThemeExtension object.
The t argument represents position on the timeline, with 0.0 meaning
that the interpolation has not started, returning a (or something
equivalent to a), 1.0 meaning that the interpolation has finished,
returning b (or something equivalent to b), and values in between
meaning that the interpolation is at the relevant point on the timeline
between a and b. The interpolation can be extrapolated beyond 0.0 and
1.0, so negative values and values greater than 1.0 are valid (and can
easily be generated by curves such as Curves.elasticInOut).
Values for t are usually obtained from an Animation<double>, such as
an AnimationController.
Implementation
@override
HintTheme lerp(HintTheme? other, double t) {
// Component-wise; when other == null (animation "theme appeared") —
// return this rather than a "black screen".
if (other == null) return this;
return HintTheme(
tooltipBackground:
Color.lerp(tooltipBackground, other.tooltipBackground, t)!,
tooltipForeground:
Color.lerp(tooltipForeground, other.tooltipForeground, t)!,
scrimColor: Color.lerp(scrimColor, other.scrimColor, t)!,
tooltipRadius: BorderRadius.lerp(tooltipRadius, other.tooltipRadius, t)!,
tooltipPadding: EdgeInsets.lerp(tooltipPadding, other.tooltipPadding, t)!,
tooltipTitleStyle:
TextStyle.lerp(tooltipTitleStyle, other.tooltipTitleStyle, t),
tooltipDescriptionStyle: TextStyle.lerp(
tooltipDescriptionStyle,
other.tooltipDescriptionStyle,
t,
),
showTail: t < 0.5 ? showTail : other.showTail,
// No lerp for the filter (filters do not interpolate) — pick by point.
imageFilter: t < 0.5 ? imageFilter : other.imageFilter,
showPulse: t < 0.5 ? showPulse : other.showPulse,
);
}