HintTourFactory class abstract
Factory for server-driven tours — HintTour from JSON.
HintTour.fromJson/toJson is the wire format
{id, steps:[{targetId,title,position}], stepTimeoutMs}.
No http dependency in hintful — bring your own fetcher (http,
dio, HttpClient, package:http, etc.).
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetch(
String id) → Future< HintTour> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited