HintTourOfferLabels class
Localizable texts of the offer dialog. All fields have defaults — pass a const with overrides for a product's own wording/l10n.
- Annotations
Constructors
Properties
- acceptLabel → String
-
final
- applyToAllPagesLabel → String
-
final
- body → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipLabel → String
-
final
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited